@@ -33,6 +33,7 @@
 #include "nautilus-file-dnd.h"
 #include "nautilus-icon-private.h"
 #include "nautilus-link.h"
+#include "nautilus-metadata.h"
 #include <eel/eel-background.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
@@ -534,7 +535,8 @@ get_background_drag_action (NautilusIconContainer *container,
 			valid_actions |= NAUTILUS_DND_ACTION_SET_AS_GLOBAL_BACKGROUND;
 		}
 
-		action = nautilus_drag_drop_background_ask (valid_actions);
+		action = nautilus_drag_drop_background_ask 
+			(GTK_WIDGET (container), valid_actions);
 	}
 
 	return action;
@@ -758,6 +760,9 @@ handle_local_move (NautilusIconContainer *container,
 	GList *moved_icons, *p;
 	NautilusDragSelectionItem *item;
 	NautilusIcon *icon;
+	NautilusFile *file;
+	char *screen_string;
+	GdkScreen *screen;
 
 	if (container->details->auto_layout) {
 		if (!confirm_switch_to_manual_layout (container)) {
@@ -766,6 +771,7 @@ handle_local_move (NautilusIconContainer *container,
 		nautilus_icon_container_freeze_icon_positions (container);
 	}
 
+
 	/* Move and select the icons. */
 	moved_icons = NULL;
 	for (p = container->details->dnd_info->drag_info.selection_list; p != NULL; p = p->next) {
@@ -774,6 +780,29 @@ handle_local_move (NautilusIconContainer *container,
 		icon = nautilus_icon_container_get_icon_by_uri
 			(container, item->uri);
 
+		if (icon == NULL) {
+			/* probably dragged from another screen.  Add it to
+			 * this screen
+			 */
+
+			file = nautilus_file_get (item->uri);
+
+			screen = gtk_widget_get_screen (GTK_WIDGET (container));
+			screen_string = g_strdup_printf ("%d",
+						gdk_screen_get_number (screen));
+			nautilus_file_set_metadata (file,
+					NAUTILUS_METADATA_KEY_SCREEN,
+					NULL, screen_string);
+
+			g_free (screen_string);
+
+			nautilus_icon_container_add (container,
+					NAUTILUS_ICON_CONTAINER_ICON_DATA (file));
+			
+			icon = nautilus_icon_container_get_icon_by_uri
+				(container, item->uri);
+		}
+
 		if (item->got_icon_position) {
 			nautilus_icon_container_move_icon
 				(container, icon,
@@ -804,7 +833,7 @@ handle_nonlocal_move (NautilusIconContainer *container,
 	if (container->details->dnd_info->drag_info.selection_list == NULL) {
 		return;
 	}
-	
+
 	source_uris = NULL;
 	for (p = container->details->dnd_info->drag_info.selection_list; p != NULL; p = p->next) {
 		/* do a shallow copy of all the uri strings of the copied files */
@@ -951,7 +980,8 @@ nautilus_icon_container_receive_dropped_icons (NautilusIconContainer *container,
 				action |= NAUTILUS_DND_ACTION_SET_AS_BACKGROUND;
 			}
 		}
-		context->action = nautilus_drag_drop_action_ask (action);
+		context->action = nautilus_drag_drop_action_ask
+			(GTK_WIDGET (container), action);
 	}
 	
 	if (context->action == NAUTILUS_DND_ACTION_SET_AS_BACKGROUND) {
