@@ -220,6 +220,7 @@ make_object (BonoboGenericFactory *factory,
 	if ((control = bonobo_object_query_local_interface
 	             (view, "IDL:Bonobo/Control:1.0"))) {
 		nautilus_view_instrument_for_failure (control, callback_data);
+		bonobo_object_unref (control);
 	}
 
 	return BONOBO_OBJECT (view);
@@ -414,7 +415,7 @@ nautilus_view_standard_main (const char *executable_name,
 						  user_data);
 }
 
-typedef GtkType (* TypeFunc) (void);
+typedef GType (* TypeFunc) (void);
 
 BonoboObject *
 nautilus_view_create_from_get_type_function (const char *iid, void *user_data)
